pqiv (0.12-1) 03_binary_name.diff

Summary

 pqiv.1.template |    4 ++--
 pqiv.c          |   18 +++++++++---------
 2 files changed, 11 insertions(+), 11 deletions(-)

    
download this patch

Patch contents

Index: pqiv-0.12/pqiv.1.template
===================================================================
--- pqiv-0.12.orig/pqiv.1.template	2012-05-18 09:57:40.000000000 +0000
+++ pqiv-0.12/pqiv.1.template	2012-05-18 13:06:28.000000000 +0000
@@ -16,7 +16,7 @@
 .\" unless NO_FADING
 .TP
 .B -F
-Make qiv fade between images. Currently this does only work for images of equal size.
+Make pqiv fade between images. Currently this does only work for images of equal size.
 .\" end
 .TP
 .B -s
@@ -117,7 +117,7 @@
 .TP
 .B -q
 Behave (mostly) like the original qiv. With this option pqiv will call
-.I qiv-command n file
+.I pqiv-command n file
 when you press a number key n, where n will be replaced by the key you pressed
 and file by the name of the current image.
 .\" end
Index: pqiv-0.12/pqiv.c
===================================================================
--- pqiv-0.12.orig/pqiv.c	2012-05-18 09:57:40.000000000 +0000
+++ pqiv-0.12/pqiv.c	2012-05-18 13:06:28.000000000 +0000
@@ -288,7 +288,7 @@
                 #ifndef NO_COMMANDS
                 " -<n> s         Set command number n (1-9) to s \n"
                 "                See manpage for advanced commands (starting with > or |) \n"
-                " -q             Use the qiv-command script for commands \n"
+                " -q             Use the pqiv-command script for commands \n"
                 #endif
 
                 "\n"
@@ -312,7 +312,7 @@
                 " v              Vertical flip \n"
                 " i              Show/hide info box \n"
                 " s              Slideshow toggle \n"
-                " a              Hardlink current image to .qiv-select/ \n"
+                " a              Hardlink current image to .pqiv-select/ \n"
                 #ifndef NO_COMMANDS
                 " <n>            Run command n (1-3) \n"
                 #endif
@@ -1955,12 +1955,12 @@
 			}
 			break;
 			/* }}} */
-		/* BIND: a: Hardlink current image to .qiv-select/ {{{ */
+		/* BIND: a: Hardlink current image to .pqiv-select/ {{{ */
 		case GDK_a:
-			mkdir("./.qiv-select", 0755);
+			mkdir("./.pqiv-select", 0755);
 			buf2 = basename(currentFile->fileName); /* Static memory, do not free */
-			buf = (char*)g_malloc(strlen(buf2) + 15);
-			sprintf(buf, "./.qiv-select/%s", buf2);
+			buf = (char*)g_malloc(strlen(buf2) + 16);
+			sprintf(buf, "./.pqiv-select/%s", buf2);
 			if(link(currentFile->fileName, buf) != 0) {
 				/* Failed to link image, try copying it */
 				if(copyFile(currentFile->fileName, buf) != TRUE) {
@@ -2436,14 +2436,14 @@
 				}
 				optionCommands[i] = g_strdup((gchar*)optarg);
 				break;
 			/* OPTION: -q: Use the qiv-command script for commands */
 			case 'q':
 				for(i=0; i<10; i++) {
 					if(optionCommands[i] != NULL) {
 						g_free(optionCommands[i]);
 					}
-					optionCommands[i] = g_strdup("qiv-command 0");
-					optionCommands[i][12] += i;
+					optionCommands[i] = g_strdup("pqiv-command 0");
+					optionCommands[i][13] += i;
 				}
 				break;
 			#endif
@@ -2436,14 +2436,14 @@
 				optionCommands[i] = g_strdup((gchar*)optarg);
 				break;
-			/* OPTION: -q: Use the qiv-command script for commands */
+			/* OPTION: -q: Use the pqiv-command script for commands */
 			case 'q':
 				for(i=0; i<10; i++) {